#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.component.hearing.interfaces import IHearingTarget
from onf_website.component.location.interfaces import ILocationTarget
from onf_website.shared.common.security import SharedToolManagerRestrictionInfo
from onf_website.shared.site.interfaces import ISiteManager
from pyams_content.shared.common.interfaces import IManagerRestrictionsFactory

# import packages
from onf_website.shared.site import Topic
from onf_website.shared.site.folder import SiteFolder
from pyams_content.shared.site.manager import SiteManager as SiteManagerBase
from pyams_utils.adapter import adapter_config
from zope.interface import implementer


@implementer(ISiteManager, ILocationTarget, IHearingTarget)
class SiteManager(SiteManagerBase):
    """Site manager class"""

    folder_factory = SiteFolder
    topic_content_factory = Topic

    handle_hearing_targets = True
    handle_hearing_privacy = True
    handle_hearing_source = True
    handle_hearing_scope = True


@adapter_config(context=ISiteManager, provides=IManagerRestrictionsFactory)
def SiteManagerRestrictionsFactory(context):
    """Site manager restrictions factory"""
    return SharedToolManagerRestrictionInfo
